@@ -3,15 +3,16 @@
 
 import re
 # 第一个datetime是包，第二个datetime是模块
-#import time
+import time
 from datetime import datetime, timedelta
-#import jieba.posseg as psg
+import jieba.posseg as psg
 import query_toolkits.utils as utils
 
 
 class Extractor:
     def __init__(self):
         self.unit_transform = utils._read_table()
+        self.organization = utils._read_list()
 
     def _check_time_valid(self, word):
         m = re.match("\d+$", word)
@@ -193,7 +194,7 @@ class Extractor:
         # 检测英文写法日期8位数字
         date_dig = re.finditer(
             "(去年|今年|前年|明年|前一年)?\d{1,2}月\d{1,2}[号|日]|\d{4}年\d{1,2}月\d{1,2}[号|日]|\d{4}[-\./]\d{1,2}[-\./]\d{1,2}|"
-            "\d{4}年\d{1,2}月|\d{4}-\d{1,2}|\d{4}\.\d{1,2}|\d{4}/\d{1,2}|"
+            "\d{4}年\d{1,2}月|\d{4}年|\d{4}-\d{1,2}|\d{4}\.\d{1,2}|\d{4}/\d{1,2}|"
             "\d{2}[:：]\d{2}([:：]\d{2})?|\d{1,2}[点｜时]\d{1,2}[分｜分钟](\d{1,2}[秒])?",
             text)
         if date_dig:
@@ -307,6 +308,27 @@ class Extractor:
         return final_res
 
 
+    def extract_reference_no(self, text):
+        org_name = None
+        year = None
+        number = None
+        another_number = None
+        query = text
+        org = utils.max_backward_match(text, self.organization, 40)
+        if len(org) > 0:
+            org = org[0]
+            org_name = org[0]
+            query = query[org[2]:]
+        res = re.search('[〔\[\(［]?\s*([0-9]{4})\s*[〕\]\)］]?\s*[年]?\s*[第]?([0-9]+)\s*号', query)
+        if res:
+            year = res.group(1)
+            number = res.group(2)
+        res = re.search('[a-zA-Z]+/[a-zA-Z]+\s*[0-9]+(\.[0-9]+)?[—-][0-9]{4}', query)
+        if res:
+            another_number = res.group(0)
+
+        return org_name, year, number, another_number
+
 
 
 
@@ -365,9 +387,11 @@ class Extractor:
 
 
 
-"""
+
 if __name__ == '__main__':
     et = Extractor()
+    res1, res2, res3, res4 = et.extract_reference_no("")
+    print(res1, res2, res3, res4)
     print(datetime.today())
     start = time.time()
     # text = "2021-03-0914:00开庭审理杨峰？"
@@ -414,12 +438,12 @@ if __name__ == '__main__':
         '1993年5月28',
         '大前年',
         '达观数据']
+    li = ["2004年2008年3月", "2050年6月21习主席", "2012.3.4", "2008年"]
     for text in li:
         cut_res = list(psg.cut(text))
         #print(text, get_range_time_from_query(text), sep=':')
         print(text)
-        res = et.time_extract(text, cut_res)
+        res = et.extract_time(text, cut_res)
         print(res)
     print((time.time() - start)/len(li))
 
-"""
\ No newline at end of file
